@@ -1,5 +1,9 @@
 amc <-
-function(y, Xmat, S, gam.method='REML', C=NULL, lambda=NULL) {
+function(y, Xmat, S, gam.method='REML', C=NULL, lambda=NULL,
+        #F allow propagating other args (like start values) to the fitter
+        ...
+        #/F
+        ) {
 	n.p = length(S)
 	if (!is.null(C)) {
 		# The following is based on Wood (2006), p. 186
@@ -15,9 +19,12 @@ function(y, Xmat, S, gam.method='REML', C=NULL, lambda=NULL) {
 		S. = S
 	}
 
-	if (is.null(lambda)) fitobj = gam(y ~ Xmat.-1, method=gam.method, paraPen=list(Xmat.=S.))
-	else fitobj = gam(y ~ Xmat.-1, paraPen=list(Xmat.=S.), sp=lambda)
-	
+    fitter = if (length(y) > 10000) bam else gam
+	#F if (is.null(lambda)) fitobj = fitter(y ~ Xmat.-1, method=gam.method, paraPen=list(Xmat.=S.))
+	#F else fitobj = fitter(y ~ Xmat.-1, paraPen=list(Xmat.=S.), sp=lambda)
+    if (is.null(lambda)) fitobj = fitter(y ~ Xmat.-1, method=gam.method, paraPen=list(Xmat.=S.), ...)
+    else fitobj = fitter(y ~ Xmat.-1, paraPen=list(Xmat.=S.), sp=lambda, ...)
+    
 	lambdavec = if (!is.null(fitobj$full.sp)) fitobj$full.sp else fitobj$sp
 	fullpen = 0
 	for (i in 1:n.p) fullpen = lambdavec[i] * S.[[i]]
